@@ -22,6 +22,7 @@ from dateutil.relativedelta import relativedelta
 from datetime import datetime
 from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
 from trytond.transaction import Transaction
+from trytond.backend import TableHandler, FIELDS
 from trytond.pyson import Eval, Not, Bool
 from trytond.pool import Pool
 
@@ -155,16 +156,20 @@ class Physician(ModelSQL, ModelView):
     'Physician'
     _name = 'gnuhealth.physician'
     _description = __doc__
+    _rec_name = 'code'
 
     name = fields.Many2One('party.party', 'Physician', required=True,
-        domain=[('is_doctor', '=', True)],
+        domain=[
+            ('is_doctor', '=', True),
+            ('is_person', '=', True),
+            ],
         help='Physician\'s Name, from the partner list')
     institution = fields.Many2One('party.party', 'Institution',
         domain=[('is_institution', '=', True)],
         help='Instituion where she/he works')
     code = fields.Char('ID', help='MD License ID')
     specialty = fields.Many2One('gnuhealth.specialty', 'Specialty',
-        help='Specialty Code')
+        required=True, help='Specialty Code')
     info = fields.Text('Extra info')
 
     def get_rec_name(self, ids, name):
@@ -308,6 +313,7 @@ class Medicament(ModelSQL, ModelView):
     'Medicament'
     _name = 'gnuhealth.medicament'
     _description = __doc__
+    _rec_name = 'active_component'
 
     name = fields.Many2One('product.product', 'Product', required=True,
         domain=[('is_medicament', '=', True)],
@@ -417,6 +423,38 @@ class PathologyCategory(ModelSQL, ModelView):
 
 PathologyCategory()
 
+class PathologyGroup(ModelSQL, ModelView):
+    'Pathology Groups'
+    _name = 'gnuhealth.pathology.group'
+    _description = __doc__
+
+    name = fields.Char('Name', required=True, translate=True,
+        help='Group name')
+    code = fields.Char('Code', required=True,
+        help='for example MDG6 code will contain the Millennium Development'\
+        ' Goals # 6 diseases : Tuberculosis, Malaria and HIV/AIDS')
+    desc = fields.Char('Short Description', required=True)
+    info = fields.Text('Detailed information')
+
+    # Upgrade from GNU Health 1.4.5
+    def init(self, module_name):
+        super(PathologyGroup, self).init(module_name)
+
+        cursor = Transaction().cursor
+        table = TableHandler(cursor, self, module_name)
+
+        # Drop old foreign key and change to char name      
+        table.drop_fk('name')
+
+        table.alter_type('name','varchar')
+
+        # Drop group column. No longer required
+        table.drop_column('group')
+        
+
+
+PathologyGroup()
+
 
 class Pathology(ModelSQL, ModelView):
     'Diseases'
@@ -425,13 +463,13 @@ class Pathology(ModelSQL, ModelView):
 
     name = fields.Char('Name', required=True, translate=True,
         help='Disease name')
-    code = fields.Char('Code',
-        help='Specific Code for the Disease (eg, ICD-10, SNOMED...\)')
+    code = fields.Char('Code', required=True, 
+        help='Specific Code for the Disease (eg, ICD-10)')
     category = fields.Many2One('gnuhealth.pathology.category', 'Main Category',
         help='Select the main category for this disease This is usually'\
         ' associated to the standard. For instance, the chapter on the ICD-10'\
         ' will be the main category for de disease')
-    groups = fields.One2Many('gnuhealth.pathology.group', 'name', 'Groups',
+    groups = fields.One2Many('gnuhealth.disease_group.members', 'name', 'Groups',
         help='Specify the groups this pathology belongs. Some automated'\
         ' processes act upon the code of the group')
     chromosome = fields.Char('Affected Chromosome', help='chromosome number')
@@ -448,22 +486,18 @@ class Pathology(ModelSQL, ModelView):
 
 Pathology()
 
-
-class PathologyGroup(ModelSQL, ModelView):
-    'Pathology Groups'
-    _name = 'gnuhealth.pathology.group'
+# DISEASE GROUP MEMBERS
+class DiseaseMembers(ModelSQL, ModelView):
+    'Disease group members'
+    _name = 'gnuhealth.disease_group.members'
     _description = __doc__
 
-    name = fields.Many2One('gnuhealth.pathology', 'Pathology', required=True)
-    group = fields.Char('Name', required=True, translate=True,
-        help='Group name')
-    code = fields.Char('Code', required=True,
-        help='for example MDG6 code will contain the Millennium Development'\
-        ' Goals # 6 diseases : Tuberculosis, Malaria and HIV/AIDS')
-    desc = fields.Char('Short Description', required=True)
-    info = fields.Text('Detailed information')
+    name = fields.Many2One('gnuhealth.pathology', 'Disease', readonly=True)
+    disease_group = fields.Many2One('gnuhealth.pathology.group', 'Group', required=True)
+
+DiseaseMembers()
+
 
-PathologyGroup()
 
 
 class ProcedureCode(ModelSQL, ModelView):
@@ -481,6 +515,7 @@ class InsurancePlan(ModelSQL, ModelView):
     'Insurance Plan'
     _name = 'gnuhealth.insurance.plan'
     _description = __doc__
+    _rec_name = 'company'
 
     name = fields.Many2One('product.product', 'Plan', required=True,
         domain=[('type', '=', 'service')],
@@ -513,6 +548,7 @@ class Insurance(ModelSQL, ModelView):
     'Insurance'
     _name = 'gnuhealth.insurance'
     _description = __doc__
+    _rec_name = 'number'
 
     name = fields.Many2One('party.party', 'Owner')
     number = fields.Char('Number', required=True)
@@ -571,7 +607,12 @@ class PartyPatient (ModelSQL, ModelView):
     internal_user = fields.Many2One('res.user', 'Internal User',
         help='In GNU Health is the user (doctor, nurse) that logins.When the'\
         ' party is a doctor or a health professional, it will be the user'\
-        ' that maps the doctor\'s party name. It must be present.')
+        ' that maps the doctor\'s party name. It must be present.',
+        states={
+            'invisible': Not(Bool(Eval('is_doctor'))),
+            'required': Bool(Eval('is_doctor')),
+            }
+        )
     insurance_company_type = fields.Selection([
         ('state', 'State'),
         ('labour_union', 'Labour Union / Syndical'),
@@ -584,8 +625,27 @@ class PartyPatient (ModelSQL, ModelView):
         super(PartyPatient, self).__init__()
         self._sql_constraints += [
             ('ref_uniq', 'UNIQUE(ref)', 'The Patient SSN must be unique'),
+            ('internal_user_uniq', 'UNIQUE(internal_user)', 'This health professional is already assigned to a party')
         ]
 
+    def write(self, ids, values):
+        # We use this method overwrite to make the fields that have a unique
+        # constraint get the NULL value at PostgreSQL level, and not the value
+        # '' coming from the client
+        if 'ref' in values and not values['ref']:
+            values = values.copy()
+            values['ref'] = None
+        return super(PartyPatient, self).write(ids, values)
+
+    def create(self, values):
+        # We use this method overwrite to make the fields that have a unique
+        # constraint get the NULL value at PostgreSQL level, and not the value
+        # '' coming from the client
+        if 'ref' in values and not values['ref']:
+            values = values.copy()
+            values['ref'] = None
+        return super(PartyPatient, self).create(values)
+
     def get_rec_name(self, ids, name):
         if not ids:
             return {}
@@ -606,10 +666,13 @@ class PartyAddress(ModelSQL, ModelView):
 
     relationship = fields.Char('Relationship',
         help='Include the relationship with the patient - friend, co-worker,'\
-        ' brother, ...')
-    relative_id = fields.Many2One('party.party', 'Relative ID',
-        domain=[('is_patient', '=', True)],
+        ' brother,...')
+    relative_id = fields.Many2One('party.party', 'Contact',
+        domain=[('is_person', '=', True)],
         help='If the relative is also a patient, please include it here')
+        
+    is_school = fields.Boolean ("School",help="Check this box to mark the school address")
+    is_work = fields.Boolean ("Work",help="Check this box to mark the work address")
 
 PartyAddress()
 
@@ -654,6 +717,7 @@ class PatientData(ModelSQL, ModelView):
     'Patient related information'
     _name = 'gnuhealth.patient'
     _description = __doc__
+    _rec_name = 'identification_code'
 
 # Get the patient age in the following format : 'YEARS MONTHS DAYS'
 # It will calculate the age of the patient while the patient is alive.
@@ -762,18 +826,24 @@ class PatientData(ModelSQL, ModelView):
         'Vaccinations')
     medications = fields.One2Many('gnuhealth.patient.medication', 'name',
         'Medications')
-    prescriptions = fields.One2Many('gnuhealth.prescription.order', 'name',
-        'Prescriptions')
+
+# Removed in 1.6
+#    prescriptions = fields.One2Many('gnuhealth.prescription.order', 'name',
+#        'Prescriptions')
+
     diseases = fields.One2Many('gnuhealth.patient.disease', 'name', 'Diseases')
     critical_info = fields.Text('Important disease, allergy or procedures'\
         ' information',
         help='Write any important information on the patient\'s disease,'\
         ' surgeries, allergies, ...')
+
+# Removed it in 1.6
 # Not used anymore . Now we relate with a shortcut. Clearer
-    evaluation_ids = fields.One2Many('gnuhealth.patient.evaluation', 'patient',
-        'Evaluation')
-    admissions_ids = fields.One2Many('gnuhealth.patient.admission', 'name',
-        'Admission / Discharge')
+#    evaluation_ids = fields.One2Many('gnuhealth.patient.evaluation', 'patient',
+#        'Evaluation')
+#    admissions_ids = fields.One2Many('gnuhealth.patient.admission', 'name',
+#        'Admission / Discharge')
+
     general_info = fields.Text('General Information',
         help='General information about the patient')
     deceased = fields.Boolean('Deceased', help='Mark if the patient has died')
@@ -1121,6 +1191,7 @@ class PatientMedication(ModelSQL, ModelView):
 PatientMedication()
 
 
+
 # PATIENT VACCINATION INFORMATION
 class PatientVaccination(ModelSQL, ModelView):
     'Patient Vaccination information'
@@ -1316,29 +1387,31 @@ class PatientEvaluation(ModelSQL, ModelView):
     evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment',
         help='Enter or select the date / ID of the appointment related to'\
         ' this evaluation')
-    evaluation_start = fields.DateTime('Start of Evaluation', required=True)
-    evaluation_endtime = fields.DateTime('End of Evaluation', required=True)
+    evaluation_start = fields.DateTime('Start', required=True)
+    evaluation_endtime = fields.DateTime('End', required=True)
     next_evaluation = fields.Many2One('gnuhealth.appointment',
         'Next Appointment')
     user_id = fields.Many2One('res.user', 'Last Changed by', readonly=True)
-    information_source = fields.Char('Information Source',help="Source of" \
+    doctor = fields.Many2One('gnuhealth.physician', 'Doctor', readonly=True)
+    specialty = fields.Many2One('gnuhealth.specialty', 'Specialty')
+    information_source = fields.Char('Source',help="Source of" \
         "Information, eg : Self, relative, friend ...")
     reliable_info = fields.Boolean ('Reliable',help="Uncheck this option" \
         "if the information provided by the source seems not reliable")
     derived_from = fields.Many2One('gnuhealth.physician',
-        'Derived from Doctor',
-        help='Physician who escalated / derived the case')
-    derived_to = fields.Many2One('gnuhealth.physician', 'Derived to Doctor',
+        'Derived from',
+        help='Physician who derived the case')
+    derived_to = fields.Many2One('gnuhealth.physician', 'Derived to',
         help='Physician to whom escalate / derive the case')
     evaluation_type = fields.Selection([
         ('a', 'Ambulatory'),
         ('e', 'Emergency'),
         ('i', 'Inpatient'),
-        ('pa', 'Pre-arraganged appointment'),
+        ('pa', 'Pre-arranged appointment'),
         ('pc', 'Periodic control'),
         ('p', 'Phone call'),
         ('t', 'Telemedicine'),
-        ], 'Evaluation Type', sort=False)
+        ], 'Type', sort=False)
     chief_complaint = fields.Char('Chief Complaint', help='Chief Complaint')
     notes_complaint = fields.Text('Complaint details')
     present_illness = fields.Text('Present Illness')
@@ -1385,81 +1458,10 @@ class PatientEvaluation(ModelSQL, ModelView):
     hip = fields.Float('Hip', help='Hip circumference in centimeters, eg 100')
     whr = fields.Float('WHR', help='Waist to hip ratio',
         on_change_with=['abdominal_circ', 'hip', 'whr'])
-    edema = fields.Boolean('Edema',
-        help='Please also encode the correspondent disease on the patient'\
-        'disease history. For example,  R60.1 in ICD-10 encoding')
-    petechiae = fields.Boolean('Petechiae')
-    hematoma = fields.Boolean('Hematomas')
-    cyanosis = fields.Boolean('Cyanosis',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history. For example,  R23.0 in ICD-10 encoding')
-    acropachy = fields.Boolean('Acropachy',
-        help='Check if the patient shows acropachy / clubbing')
-    nystagmus = fields.Boolean('Nystagmus',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history. For example,  H55 in ICD-10 encoding')
-    miosis = fields.Boolean('Miosis',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history. For example,  H57.0 in ICD-10 encoding')
-    mydriasis = fields.Boolean('Mydriasis',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history. For example,  H57.0 in ICD-10 encoding')
-    cough = fields.Boolean('Cough',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history.')
-    palpebral_ptosis = fields.Boolean('Palpebral Ptosis',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    arritmia = fields.Boolean('Arritmias',
-        help='If associated  to a disease, please encode it on thepatient'\
-        ' disease history')
-    heart_murmurs = fields.Boolean('Heart Murmurs')
-    heart_extra_sounds = fields.Boolean('Heart Extra Sounds',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    jugular_engorgement = fields.Boolean('Jugular Engorgement',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    ascites = fields.Boolean('Ascites',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    lung_adventitious_sounds = fields.Boolean('Lung Adventitious sounds',
-        help='Crackles, wheezes, ronchus..')
-    bronchophony = fields.Boolean('Bronchophony')
-    increased_fremitus = fields.Boolean('Increased Fremitus')
-    decreased_fremitus = fields.Boolean('Decreased Fremitus')
-    jaundice = fields.Boolean('Jaundice',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    lynphadenitis = fields.Boolean('Linphadenitis',
-        help='If associated  to a disease, please encode it on the patient'\
-        ' disease history')
-    breast_lump = fields.Boolean('Breast Lumps')
-    breast_asymmetry = fields.Boolean('Breast Asymmetry')
-    nipple_inversion = fields.Boolean('Nipple Inversion')
-    nipple_discharge = fields.Boolean('Nipple Discharge')
-    peau_dorange = fields.Boolean('Peau d orange',
-        help='Check if the patient has prominent pores in the skin of the'\
-        ' breast')
-    gynecomastia = fields.Boolean('Gynecomastia')
 
-    masses = fields.Boolean('Masses',
-        help='Check when there are findings of masses / tumors / lumps')
-    hypotonia = fields.Boolean('Hypotonia',
-        help='Please also encode the correspondent disease on the patient'\
-        ' disease history.')
-    hypertonia = fields.Boolean('Hypertonia',
-        help='Please also encode the correspondent disease on the patient'\
-        ' disease history.')
-    pressure_ulcers = fields.Boolean('Pressure Ulcers',
-        help='Check when Decubitus / Pressure ulcers are present')
-    goiter = fields.Boolean('Goiter')
-    alopecia = fields.Boolean('Alopecia',
-        help='Check when alopecia - including androgenic - is present')
-    xerosis = fields.Boolean('Xerosis')
-    erithema = fields.Boolean('Erithema',
-        help='Please also encode the correspondent disease on the patient'\
-        ' disease history.')
+# DEPRECATION NOTE : SIGNS AND SYMPTOMS FIELDS TO BE REMOVED IN 1.6 .
+# NOW WE USE A O2M OBJECT TO MAKE IT MORE SCALABLE, CLEARER AND FUNCTIONAL
+# TO WORK WITH THE CLINICAL FINDINGS OF THE PATIENT
     loc = fields.Integer('Level of Consciousness',
         on_change_with=['loc_verbal', 'loc_motor', 'loc_eyes'],
         help='Level of Consciousness - on Glasgow Coma Scale :  1=coma -'\
@@ -1533,99 +1535,47 @@ class PatientEvaluation(ModelSQL, ModelView):
         help='Check this box if the patient is unable to make voluntary'\
         'movements')
     diagnosis = fields.Many2One('gnuhealth.pathology', 'Presumptive Diagnosis',
-        help='Presumptive Diagnosis')
+        help='Presumptive Diagnosis. If no diagnosis can be made'\
+        ', encode the main sign or symptom.')
+    secondary_conditions = fields.One2Many('gnuhealth.secondary_condition',
+        'evaluation', 'Secondary Conditions', help="Other, Secondary conditions found on the patient")
+
     diagnostic_hypothesis = fields.One2Many('gnuhealth.diagnostic_hypothesis',
         'evaluation', 'Hypotheses / DDx', help="Other Diagnostic Hypotheses / Differential Diagnosis (DDx)")
     signs_and_symptoms = fields.One2Many('gnuhealth.signs_and_symptoms',
-        'evaluation', 'Signs and Symptoms', help="Enter the Signs and Symptoms for the patient in this evaluation")
-
+        'evaluation', 'Signs and Symptoms', help="Enter the Signs and Symptoms for the patient in this evaluation.")
     info_diagnosis = fields.Text('Presumptive Diagnosis: Extra Info')
     directions = fields.Text('Plan')
     actions = fields.One2Many('gnuhealth.directions', 'name', 'Procedures',
         help='Procedures / Actions to take')
-    symptom_pain = fields.Boolean('Pain')
-    symptom_pain_intensity = fields.Integer('Pain intensity',
-        help='Pain intensity from 0(no pain) to 10(worst possible pain)')
-    symptom_arthralgia = fields.Boolean('Arthralgia')
-    symptom_myalgia = fields.Boolean('Myalgia')
-    symptom_abdominal_pain = fields.Boolean('Abdominal Pain')
-    symptom_cervical_pain = fields.Boolean('Cervical Pain')
-    symptom_thoracic_pain = fields.Boolean('Thoracic Pain')
-    symptom_lumbar_pain = fields.Boolean('Lumbar Pain')
-    symptom_pelvic_pain = fields.Boolean('Pelvic Pain')
-    symptom_headache = fields.Boolean('Headache')
-    symptom_odynophagia = fields.Boolean('Odynophagia')
-    symptom_sore_throat = fields.Boolean('Sore throat')
-    symptom_otalgia = fields.Boolean('Otalgia')
-    symptom_tinnitus = fields.Boolean('Tinnitus')
-    symptom_ear_discharge = fields.Boolean('Ear Discharge')
-    symptom_hoarseness = fields.Boolean('Hoarseness')
-    symptom_chest_pain = fields.Boolean('Chest Pain')
-    symptom_chest_pain_excercise = fields.Boolean('Chest Painon excercise'\
-        ' only')
-    symptom_orthostatic_hypotension = fields.Boolean('Orthostatic hypotension',
-        help='If associated  to a disease,please encode it on the patient'\
-        ' disease history. For example,  I95.1 in ICD-10 encoding')
-    symptom_astenia = fields.Boolean('Astenia')
-    symptom_anorexia = fields.Boolean('Anorexia')
-    symptom_weight_change = fields.Boolean('Sudden weight change')
-    symptom_abdominal_distension = fields.Boolean('Abdominal Distension')
-    symptom_hemoptysis = fields.Boolean('Hemoptysis')
-    symptom_hematemesis = fields.Boolean('Hematemesis')
-    symptom_epistaxis = fields.Boolean('Epistaxis')
-    symptom_gingival_bleeding = fields.Boolean('Gingival Bleeding')
-    symptom_rinorrhea = fields.Boolean('Rinorrhea')
-    symptom_nausea = fields.Boolean('Nausea')
-    symptom_vomiting = fields.Boolean('Vomiting')
-    symptom_dysphagia = fields.Boolean('Dysphagia')
-    symptom_polydipsia = fields.Boolean('Polydipsia')
-    symptom_polyphagia = fields.Boolean('Polyphagia')
-    symptom_polyuria = fields.Boolean('Polyuria')
-    symptom_nocturia = fields.Boolean('Nocturia')
-    symptom_vesical_tenesmus = fields.Boolean('Vesical Tenesmus')
-    symptom_pollakiuria = fields.Boolean('Pollakiuiria')
-    symptom_dysuria = fields.Boolean('Dysuria')
-    symptom_stress = fields.Boolean('Stressed-out')
-    symptom_mood_swings = fields.Boolean('Mood Swings')
-    symptom_pruritus = fields.Boolean('Pruritus')
-    symptom_insomnia = fields.Boolean('Insomnia')
-    symptom_disturb_sleep = fields.Boolean('Disturbed Sleep')
-    symptom_dyspnea = fields.Boolean('Dyspnea')
-    symptom_orthopnea = fields.Boolean('Orthopnea')
-    symptom_amnesia = fields.Boolean('Amnesia')
-    symptom_paresthesia = fields.Boolean('Paresthesia')
-    symptom_paralysis = fields.Boolean('Paralysis')
-    symptom_syncope = fields.Boolean('Syncope')
-    symptom_dizziness = fields.Boolean('Dizziness')
-    symptom_vertigo = fields.Boolean('Vertigo')
-    symptom_eye_glasses = fields.Boolean('Eye glasses',
-        help='Eye glasses or contact lenses')
-    symptom_blurry_vision = fields.Boolean('Blurry vision')
-    symptom_diplopia = fields.Boolean('Diplopia')
-    symptom_photophobia = fields.Boolean('Photophobia')
-    symptom_dysmenorrhea = fields.Boolean('Dysmenorrhea')
-    symptom_amenorrhea = fields.Boolean('Amenorrhea')
-    symptom_metrorrhagia = fields.Boolean('Metrorrhagia')
-    symptom_menorrhagia = fields.Boolean('Menorrhagia')
-    symptom_vaginal_discharge = fields.Boolean('Vaginal Discharge')
-    symptom_urethral_discharge = fields.Boolean('Urethral Discharge')
-    symptom_diarrhea = fields.Boolean('Diarrhea')
-    symptom_constipation = fields.Boolean('Constipation')
-    symptom_rectal_tenesmus = fields.Boolean('Rectal Tenesmus')
-    symptom_melena = fields.Boolean('Melena')
-    symptom_proctorrhagia = fields.Boolean('Proctorrhagia')
-    symptom_xerostomia = fields.Boolean('Xerostomia')
-    symptom_sexual_dysfunction = fields.Boolean('Sexual Dysfunction')
+
+
     notes = fields.Text('Notes')
 
+    def default_doctor(self):
+        cursor = Transaction().cursor
+        user_obj = Pool().get('res.user')
+        user = user_obj.browse(Transaction().user)
+        login_user_id = int(user.id)
+        cursor.execute ('SELECT id FROM party_party WHERE is_doctor=True AND internal_user = %s LIMIT 1',(login_user_id,))
+        partner_id = cursor.fetchone()
+        if not partner_id:
+            self.raise_user_error('No health professional associated to this user')
+        else:    
+            cursor = Transaction().cursor
+            cursor.execute ('SELECT id FROM gnuhealth_physician WHERE name = %s LIMIT 1',(partner_id[0],))
+            doctor_id = cursor.fetchone()
+
+            return int(doctor_id[0])
+
     def default_loc_eyes(self):
-        return 4
+        return '4'
 
     def default_loc_verbal(self):
-        return 5
+        return '5'
 
     def default_loc_motor(self):
-        return 6
+        return '6'
 
     def default_evaluation_type(self):
         return 'pa'
@@ -1679,6 +1629,20 @@ class Directions(ModelSQL, ModelView):
 Directions()
 
 
+
+# SECONDARY CONDITIONS ASSOCIATED TO THE PATIENT IN THE EVALUATION
+class SecondaryCondition(ModelSQL, ModelView):
+    'Secondary Conditions'
+    _name = 'gnuhealth.secondary_condition'
+    _description = __doc__
+
+    evaluation = fields.Many2One('gnuhealth.patient.evaluation', 'Evaluation', readonly=True)
+    pathology = fields.Many2One('gnuhealth.pathology', 'Pathology', required=True)
+    comments = fields.Char('Comments')
+
+SecondaryCondition()
+
+
 # PATIENT EVALUATION OTHER DIAGNOSTIC HYPOTHESES
 class DiagnosticHypothesis(ModelSQL, ModelView):
     'Other Diagnostic Hypothesis'
@@ -1818,6 +1782,7 @@ class HospitalBed(ModelSQL, ModelView):
     'Hospital Bed'
     _name = 'gnuhealth.hospital.bed'
     _description = __doc__
+    _rec_name = 'telephone_number'
 
     name = fields.Many2One('product.product', 'Bed', required=True,
         domain=[('is_bed', '=', True)],
